@@ -2,9 +2,16 @@
  * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
  */
 
-#include "embryo_private.h"
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include <stdlib.h>
 #include <time.h>
 
+#include "Embryo.h"
+#include "embryo_private.h"
+
 static int _embryo_init_count = 0;
 
 /*** EXPORTED CALLS ***/
@@ -24,8 +31,8 @@ static int _embryo_init_count = 0;
 EAPI int
 embryo_init(void)
 {
-   _embryo_init_count++;
-   if (_embryo_init_count > 1) return _embryo_init_count;
+   if (++_embryo_init_count != 1)
+     return _embryo_init_count;
 
    srand(time(NULL));
 
@@ -41,8 +48,8 @@ embryo_init(void)
 EAPI int
 embryo_shutdown(void)
 {
-   _embryo_init_count--;
-   if (_embryo_init_count > 0) return _embryo_init_count;
+   if (--_embryo_init_count != 0)
+     return _embryo_init_count;
 
    return _embryo_init_count;
 }
